@@ -9,7 +9,7 @@ use DynaLoader();
 use Carp ();
 @ISA = qw(DynaLoader);
 
-$VERSION = '2.9003_1';
+$VERSION = '2.9004_2';
 
 bootstrap DBD::mysql $VERSION;
 
@@ -171,6 +171,7 @@ sub admin {
 
 package DBD::mysql::db; # ====== DATABASE ======
 use strict;
+use DBI qw(:sql_types);
 
 %DBD::mysql::db::db2ANSI = ("INT"   =>  "INTEGER",
 			   "CHAR"  =>  "CHAR",
@@ -712,7 +713,7 @@ to mysql_ssl_set, if mysql_ssl is turned on.
 As of MySQL 3.23.49, the LOCAL capability for LOAD DATA may be disabled
 in the MySQL client library by default. If your DSN contains the option
 "mysql_local_infile=1", LOAD DATA LOCAL will be enabled.  (However,
-this option is effective if the server has also been configured to
+this option is *ineffective* if the server has also been configured to
 disallow LOCAL.)
 
 
@@ -1678,9 +1679,9 @@ in the PPM program.
 =head1 AUTHORS
 
 The current version of B<DBD::mysql> is almost completely written
-by Jochen Wiedmann (I<joe@ispsoft.de>), and is now being maintained by
+by Jochen Wiedmann, and is now being maintained by
 Rudy Lippan (I<rlippan@remotelinux.com>). The first version's author
-was Alligator Descartes(I<descarte@symbolstone.org>), who has been
+was Alligator Descartes (I<descarte@symbolstone.org>), who has been
 aided and abetted by Gary Shea, Andreas Knig and Tim Bunce
 amongst others.
 
@@ -1693,7 +1694,7 @@ layer, is from Jochen Wiedmann.
 
 
 This module is Copyright (c) 2003 Rudolf Lippan; Large Portions 
-Copyright (c) 1997-2001 Jochen Wiedmann, with code portions 
+Copyright (c) 1997-2003 Jochen Wiedmann, with code portions 
 Copyright (c)1994-1997 their original authors This module is
 released under the same license as Perl itself. See the Perl README
 for details.
@@ -1703,15 +1704,15 @@ for details.
 
 This module is maintained and supported on a mailing list,
 
-    msql-mysql-modules@lists.mysql.com
+    perl@lists.mysql.com
 
 To subscribe to this list, send a mail to
 
-    msql-mysql-modules-subscribe@lists.mysql.com
+    perl-subscribe@lists.mysql.com
 
 or
 
-    msql-mysql-modules-digest-subscribe@lists.mysql.com
+    perl-digest-subscribe@lists.mysql.com
 
 Mailing list archives are available at
 
